
import { createRouter, createWebHistory } from 'vue-router'
import HomeView from '@/views/HomeView.vue'
import LoginView from '@/views/LoginView.vue'
import NotFoundView from '@/views/NotFoundView.vue'
import AktifIndividual from '@/components/Pages/DaftarTransaksi/AktifIndividual.vue'
import EmptyPage from '@/components/Pages/HomeEmpty.vue'
import { useAuthStore } from '@/stores/auth'
const router = createRouter({
  history: createWebHistory(import.meta.env.BASE_URL),
  linkActiveClass: 'active',
  routes: [
    {
      path: '/home',
      name: 'Home',
      'meta': { requiresAuth: true },
      component: HomeView,
      children: [
        {
          path: '',
          name: 'Home Page',
          component: EmptyPage,
        },
        {
          path: 'daftar-transaksi',
          name: 'Daftar Transaksi',
          children: [
            {
              path: 'aktif-individual',
              name: 'Transaksi Aktif Individual',
              component: AktifIndividual,
            },
            {
              path: 'aktif-pln-mobile',
              name: 'Transaksi Aktif PLN Mobile',
              component: EmptyPage,
            },
            {
              path: 'periksa-return-order',
              name: 'Transaksi Aktif Periksa dan Return Order',
              component: EmptyPage,
            },
            {
              path: 'aktif-tm',
              name: 'Transaksi Aktif TM',
              component: EmptyPage,
            },
            {
              path: 'aktif-historis',
              name: 'Transaksi Aktif Historis',
              component: EmptyPage,
            },
            {
              path: 'monitoring-alih-unit',
              name: 'Monitoring Alih Unit',
              component: EmptyPage,
            },
            {
              path: 'monitoring-all',
              name: 'Monitoring All',
              component: EmptyPage,
            },
            {
              path: 'monitoring-tiket',
              name: 'Monitoring Tiket',
              component: EmptyPage,
            },
            {
              path: 'monitoring-history',
              name: 'Monitoring History',
              component: EmptyPage,
            },
            {
              path: 'monitoring-aktif',
              name: 'Monitoring Aktif',
              component: EmptyPage,
            },
            {
              path: 'monitoring-close-cc',
              name: 'Monitoring Close CC',
              component: EmptyPage,
            },
            {
              path: 'monitoring-log-autodispatch',
              name: 'Monitoring Log AutoDispatch',
              component: EmptyPage,
            },
            {
              path: 'monitoring-perlu-diperhatikan',
              name: 'Monitoring yang Perlu Diperhatikan',
              component: EmptyPage,
            },
            {
              path: 'monitoring-log-break-regu',
              name: 'Monitoring Log Break Regu',
              component: EmptyPage,
            },
            {
              path: 'monitoring-log-alih-regu',
              name: 'Monitoring Log Alih Regu',
              component: EmptyPage,
            },
          ]
        },
        {
          path: 'administration',
          name: 'Administration',
          children: [
            {
              path: 'audit-trails',
              name: 'Audit Trails',
              children: [
                {
                  path: 'log-login',
                  name: 'Log Login',
                  component: EmptyPage,
                },
                {
                  path: 'log-aktivity',
                  name: 'Log Aktivity',
                  component: EmptyPage,
                },
                {
                  path: 'log-error',
                  name: 'Log Error',
                  component: EmptyPage,
                },
              ],
            },
            {
              path: 'task-management',
              name: 'Task Management',
              children: [
                {
                  path: 'menu-management',
                  name: 'Menu Management',
                  component: EmptyPage,
                },
                {
                  path: 'system-parameter',
                  name: 'System Parameter',
                  component: EmptyPage,
                },
                {
                  path: 'ubah-profile-manager',
                  name: 'Ubah Profile Manager',
                  component: EmptyPage,
                },
                {
                  path: 'security-projek',
                  name: 'Security Projek',
                  component: EmptyPage,
                },
                {
                  path: 'user-role-manager',
                  name: 'User Role Manager',
                  component: EmptyPage,
                },
                {
                  path: 'menu-authorization',
                  name: 'Menu Authorization',
                  component: EmptyPage,
                },
                {
                  path: 'workflow-designer',
                  name: 'Workflow Designer',
                  component: EmptyPage,
                },
                {
                  path: 'apkt-news',
                  name: 'APKT News',
                  component: EmptyPage,
                },
              ],
            },
            {
              path: 'master-borderless',
              name: 'Master Borderless',
              children: [
                {
                  path: 'zone-borderless',
                  name: 'Zone Borderless',
                  component: EmptyPage,
                },
                {
                  path: 'user-zone-borderless',
                  name: 'User Zone Borderless',
                  component: EmptyPage,
                },
              ],
            },
          ],
        },
        {
          path: 'master-yantek',
          name: 'Master Yantek',
          children: [
            {
              path: 'unit',
              name: 'Unit',
              component: EmptyPage,
            },
            {
              path: 'unit-jaringan',
              name: 'Unit Jaringan',
              component: EmptyPage,
            },
            {
              path: 'unit-pelayanan',
              name: 'Unit Pelayanan',
              component: EmptyPage,
            },
            {
              path: 'regu-yantek',
              name: 'Regu Yantek',
              component: EmptyPage,
            },
            {
              path: 'gardu-induk',
              name: 'Gardu Induk',
              component: EmptyPage,
            },
            {
              path: 'gardu-penyulang-tm',
              name: 'Gardu Penyulang TM',
              component: EmptyPage,
            },
            {
              path: 'gardu-distribusi',
              name: 'Gardu Distribusi',
              component: EmptyPage,
            },
            {
              path: 'group-gangguan',
              name: 'Group Gangguan',
              component: EmptyPage,
            },
            {
              path: 'wilayah-yantek',
              name: 'Wilayah Yantek',
              component: EmptyPage,
            },
            {
              path: 'material',
              name: 'Material',
              component: EmptyPage,
            },
          ]
        },
        {
          path: 'transaksi',
          name: 'Transaksi',
          children: [
            {
              path: 'gangguan-dan-keluhan',
              name: 'Gangguan dan Keluhan',
              component: EmptyPage,
            },
            {
              path: 'gangguan-tegangan-menengah',
              name: 'Gangguan Tegangan Menengah',
              component: EmptyPage,
            },
            {
              path: 'pemadaman-terencana',
              name: 'Pemadaman Terencana',
              component: EmptyPage,
            },
            {
              path: 'aplikasi-off-line',
              name: 'Aplikasi Off-Line',
              component: EmptyPage,
            },
            {
              path: 'penugasan-khusus',
              name: 'Penugasan Khusus',
              component: EmptyPage,
            },
            {
              path: 'mutasi-pengaduan',
              name: 'Mutasi Pengaduan',
              component: EmptyPage,
            },
          ]
        },
      ]
    },
    {
      path: '/login',
      name: 'Login',
      component: LoginView
    },
    {
      path: '/logout',
      name: 'Logout',
      beforeEnter(to, from, next) {
        const auth = useAuthStore()
        auth.logout()
        next('/login')
      },
      redirect: '/logout'
    },
    {
      path: '/404',
      name: 'Not Found',
      component: NotFoundView
    },
  ]
})

router.beforeEach((to, from, next) => {
  // redirect to login page if not logged in and trying to access a restricted page
  const auth = useAuthStore();

  // if to is not found, redirect to 404
  if (to.matched.length === 0) {
    if (to.path === '/') {
      if (auth.isLoggedIn) {
        next('/home')
      } else {
        next('/login')
      }
    } else {
      next('/404')
    }
  } else {
    // if to is not login and user is not logged in, redirect to login
    if (auth.isLoggedIn) {
      // if to is login and user is logged in, redirect to home
      if (to.path === '/login') {
        next('/home')
      } else {
        next()
      }
    } else {
      // if to is 404, redirect to 404
      if (to.path !== '/404' && to.path !== '/login') {
        next('/login')
      } else {
        next()
      }
    }
  }

})

export default router
